@@ -25,11 +25,12 @@ class AdsApi:
         for attempt in range(attempts):
             try:
                 self.lock.acquire()
-                sleep(1)  # because limite 1 request per second
-                d_n = data.copy()
-                for i in d_n:
-                    if not data[i]:
-                        del data[i]
+                sleep(1)  # because limite 1 request per second\
+                if data:
+                    d_n = data.copy()
+                    for i in d_n:
+                        if data[i] == None:
+                            del data[i]
                 response = methods[method](
                     self.base_url_ads + endpoint, params=params, data=data).json()
                 self.lock.release()
